@@ -3,24 +3,29 @@ import numpy as np
 from scipy.spatial import cKDTree
 
 
-def rdf2d(particles, dr, rho=None, eps=1e-15):
+def rdf2d(particles, dr, rho=None, rcutoff=0.8, eps=1e-15, progress=False):
     """
-    Computes 2D radial disribution functions g(r) of a set of particles of shape (N, 2).
+    Computes 2D radial distribution functions g(r) of a set of particles of shape (N, 2).
     Particle must be placed in a 2D box of dimensions (width x height).
-    
+   
     Parameters
     ----------
     particles : (N, 2) np.array
-        Set of particle from which to compute the radial distribution funntion g(r).
+        Set of particle from which to compute the radial distribution function g(r).
     dr : float
         Delta r. Determines the spacing between successive radii over which g(r) is computed.
     rho : float, optional
-        Number density. In cases where the number of particles is relatively low, or the 
-        particle:box size ratio is small, it may be better to provide your own number density 
-        for more accurate results. If left as None, box dimensions will be inferred from the 
+        Number density. If left as None, box dimensions will be inferred from the
         particles and the number density will be calculated accordingly.
+    rcutoff : float
+        radii cutoff value between 0 and 1. The default value of 0.8 means the independent
+        variable (radius) over which the RDF is computed will range from 0 to 0.8*r_max. 
+        This removes the noise that occurs at r values close to r_max, due to fewer valid 
+        particles available to compute the RDF from at these r values.
     eps : float, optional
         Epsilon value used to find particles less than or equal to a distance in KDTree.
+    progress : bool, optional
+        Set to False to disable progress readout.
         
     
     Returns
@@ -49,45 +54,54 @@ def rdf2d(particles, dr, rho=None, eps=1e-15):
     if not rho:
         rho = N / (w*h) # number density
 
-    # create a KDTree for fast nearest-neighbour lookup of particles
+    # create a KDTree for fast nearest-neighbor lookup of particles
     tree = cKDTree(particles)
     
     for r_idx, r in enumerate(radii):
+        # find all particles that are at least r + dr away from the edges of the box
         valid_idxs = (particles[:, 0]-(r+dr) >= min_x) & (particles[:, 0]+(r+dr) <= max_x) \
                    & (particles[:, 1]-(r+dr) >= min_y) & (particles[:, 1]+(r+dr) <= max_y)
         valid_particles = particles[valid_idxs]
         
+        # compute n_i(r) for valid particles.
         for particle in valid_particles:
             n = tree.query_ball_point(particle, r+dr-eps, return_length=True) - tree.query_ball_point(particle, r, return_length=True)
             g_r[r_idx] += n
         
+        # normalize
         n_valid = len(valid_particles)
         shell_vol = np.pi*((r+dr)**2 - r**2)
         g_r[r_idx] /= n_valid*shell_vol*rho
 
-        print('Computing RDF     Radius {}/{}    Time elapsed: {:.3f} s'.format(r_idx+1, len(radii), time.time()-start), end='\r', flush=True)
+        if progress:
+            print('Computing RDF     Radius {}/{}    Time elapsed: {:.3f} s'.format(r_idx+1, len(radii), time.time()-start), end='\r', flush=True)
         
     return g_r, radii
 
 
-def rdf3d(particles, dr, rho=None, eps=1e-15):
+def rdf3d(particles, dr, rho=None, rcutoff=0.8, eps=1e-15, progress=False):
     """
-    Computes 3D radial disribution functions g(r) of a set of particles of shape (N, 3).
+    Computes 3D radial distribution functions g(r) of a set of particles of shape (N, 3).
     Particle must be placed in a 3D cuboidal box of dimensions (width x height x depth).
     
     Parameters
     ----------
     particles : (N, 3) np.array
-        Set of particle from which to compute the radial distribution funntion g(r).
+        Set of particle from which to compute the radial distribution function g(r).
     dr : float
         Delta r. Determines the spacing between successive radii over which g(r) is computed.
     rho : float, optional
-        Number density. In cases where the number of particles is relatively low, or the 
-        particle:box size ratio is small, it may be better to provide your own number density 
-        for more accurate results. If left as None, box dimensions will be inferred from the 
+        Number density. If left as None, box dimensions will be inferred from the 
         particles and the number density will be calculated accordingly.
+    rcutoff : float
+        radii cutoff value between 0 and 1. The default value of 0.8 means the independent
+        variable (radius) over which the RDF is computed will range from 0 to 0.8*r_max. 
+        This removes the noise that occurs at r values close to r_max, due to fewer valid 
+        particles available to compute the RDF from at these r values.
     eps : float, optional
         Epsilon value used to find particles less than or equal to a distance in KDTree.
+    progress : bool, optional
+        Set to False to disable progress readout.
         
     
     Returns
@@ -116,23 +130,27 @@ def rdf3d(particles, dr, rho=None, eps=1e-15):
     if not rho:
         rho = N / (w*h*d) # number density
 
-    # create a KDTree for fast nearest-neighbour lookup of particles
+    # create a KDTree for fast nearest-neighbor lookup of particles
     tree = cKDTree(particles)
     
     for r_idx, r in enumerate(radii):
+        # find all particles that are at least r + dr away from the edges of the box
         valid_idxs = (particles[:, 0]-(r+dr) >= min_x) & (particles[:, 0]+(r+dr) <= max_x) \
                    & (particles[:, 1]-(r+dr) >= min_y) & (particles[:, 1]+(r+dr) <= max_y) \
                    & (particles[:, 2]-(r+dr) >= min_z) & (particles[:, 2]+(r+dr) <= max_z)
         valid_particles = particles[valid_idxs]
         
+        # compute n_i(r) for valid particles.
         for particle in valid_particles:
             n = tree.query_ball_point(particle, r+dr-eps, return_length=True) - tree.query_ball_point(particle, r, return_length=True)
             g_r[r_idx] += n
         
+        # normalize
         n_valid = len(valid_particles)
         shell_vol = (4/3)*np.pi*((r+dr)**3 - r**3)
         g_r[r_idx] /= n_valid*shell_vol*rho
 
-        print('Computing RDF     Radius {}/{}    Time elapsed: {:.3f} s'.format(r_idx+1, len(radii), time.time()-start), end='\r', flush=True)
+        if progress:
+            print('Computing RDF     Radius {}/{}    Time elapsed: {:.3f} s'.format(r_idx+1, len(radii), time.time()-start), end='\r', flush=True)
         
     return g_r, radii
